# Fork of official Python STEEM Library
`steep-steem` is the fork of official STEEM library for Python. It comes with a BIP38 encrypted wallet and a practical CLI utility called `steeppy`.

## Installation
You can install `steep-steem` with `pip`:

```
pip install -U steep-steem
```

## Notice
This library is under *active development*. Use at own discretion.

